@@ -1,3 +1,3 @@
-from .organization import DataPackage, ButtonEvent  # noqa: F401
+from .organization import DataPackage, RawDataPackage, ButtonEvent  # noqa: F401
 from .enums import ButtonAction, ButtonId  # noqa: F401
 from .points import Euler3d, Point3d, Quaternion  # noqa: F401
