@@ -11,6 +11,9 @@ class Point3d:
     def __sub__(self, other):
         return Point3d(x=self.x - other.x, y=self.y - other.y, z=self.z - other.z)
 
+    def as_dict(self, prefix: str = ""):
+        return {f"{prefix}x": self.x, f"{prefix}y": self.y, f"{prefix}z": self.z}
+
 
 @dataclass(frozen=True)
 class Euler3d:
@@ -18,6 +21,9 @@ class Euler3d:
     pitch: float
     yaw: float
 
+    def as_dict(self, prefix: str = ""):
+        return {f"{prefix}roll": self.roll, f"{prefix}pitch": self.pitch, f"{prefix}yaw": self.yaw}
+
 
 @dataclass(frozen=True)
 class Quaternion:
@@ -50,6 +56,9 @@ class Quaternion:
         norm = math.sqrt(sum([el**2 for el in [self.w, self.x, self.y, self.z]]))
         return Quaternion(self.w / norm, self.x / norm, self.y / norm, self.z / norm)
 
+    def as_dict(self, prefix: str = ""):
+        return {f"{prefix}w": self.w, f"{prefix}x": self.x, f"{prefix}y": self.y, f"{prefix}z": self.z}
+
 
 def rotate_vector(p: Point3d, q: Quaternion) -> Point3d:
     """Rotate point p by quaternion q"""
